@@ -1,5 +1,5 @@
 from .structure_learning import hc, pc_stable, ges
 from .evaluation import f1, shd
 from .accessory import miss_mechanism, add_missing, dag2cpdag, from_bnlearn, to_bnlearn, pdag2dag, edges, parents, \
-    neighbours, g_test, cor_test
+    neighbours, g_test, pearson_test
 from .score import score
