@@ -6,7 +6,7 @@ import numpy as np
 import pandas
 
 pandas.options.mode.chained_assignment = None
-from .accessory import g_test, cor_test, find_causes, pairwise, dag2cpdag, orient_v_structure, orient_propagation, \
+from .accessory import g_test, pearson_test, find_causes, pairwise, dag2cpdag, orient_v_structure, orient_propagation, \
     to_bnlearn
 from .score import local_score
 
